/***********************************************************************
* Copyright (c) 2011 Samu Juvonen <samu.juvonen@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
************************************************************************/

#include "BookmarkDialog.h"
#include "BookmarkModel.h"

#include "ui_BookmarkDialog.h"

BookmarkDialog::BookmarkDialog(QWidget * parent) : QDialog(parent) {
	_ui = new Ui::BookmarkDialog;
	_ui->setupUi(this);

	connect(_ui->bookmarks, SIGNAL(currentIndexChanged(int)), SLOT(showBookmark(int)));
}

void BookmarkDialog::setModel(BookmarkModel * model) {
	_ui->bookmarks->setModel(model);
}

BookmarkModel * BookmarkDialog::model() const {
	return qobject_cast<BookmarkModel *>(_ui->bookmarks->model());
}



void BookmarkDialog::addBookmark() {

	if (_ui->location->text().isEmpty())
		return;
	
	if (model())
		model()->addPath(_ui->location->text(), _ui->name->text());
}

void BookmarkDialog::removeBookmark() {
	if (!model())
		return;

	model()->removeRow( _ui->bookmarks->currentIndex() );
}

void BookmarkDialog::showBookmark(int row) {
	if (!model())
		return;
	
	const QModelIndex idx = model()->index(row, 0);

	_ui->location->setText(idx.data(BookmarkModel::FilePathRole).toString());
	_ui->name->setText(idx.data(BookmarkModel::DisplayNameRole).toString());
}